@@ -43,7 +43,8 @@ sub process_swig_files {
     }
 
     my $binding_ver = $self->get_binding_version;
-    print "Process XS files version $binding_ver\n";
+    my $current_version = $self->{properties}->{current_version};
+    print "Process XS files version $binding_ver (GSL version $current_version)\n";
     foreach my $file (@$files_ref) {
         $self->process_xs_file($file->[0], $binding_ver);
     }
@@ -112,7 +113,9 @@ sub process_xs_file {
     my ($self, $main_swig_file, $ver) = @_;
 
     (my $file_base = $main_swig_file) =~ s/\.[^.]+$//;
-    $file_base =~ s!swig/!!g;
+    $file_base =~ s!\\!/!g;
+    (undef, undef, $file_base) = splitpath($file_base);
+
     my $c_file = catfile('xs',"${file_base}_wrap.$ver.c");
 
     # .c -> .o
@@ -159,6 +162,23 @@ sub process_swig {
         unless($self->up_to_date([$main_swig_file, @deps], $c_file));
 }
 
+sub swig_binary_name {
+    # recent versions of Ubuntu call it swig2.0 . Le sigh.
+    my $cmd = "swig -version";
+    my $out = `$cmd`;
+    if ($?) {
+        $cmd = "swig2.0 -version";
+        $out = `$cmd`;
+
+        if ($?) {
+            die "Can't find the swig binary!";
+        } else {
+            return "swig2.0";
+        }
+    }
+    return "swig";
+}
+
 # Invoke swig with -perl -outdir and other options.
 sub compile_swig {
     my ($self, $file, $c_file, $ver) = @_;
@@ -172,7 +192,7 @@ sub compile_swig {
 
     my $pm_file = "${file_base}.pm";
 
-    my @swig       = qw/swig/, defined($p->{swig}) ? ($self->split_like_shell($p->{swig})) : ();
+    my @swig       = swig_binary_name(), defined($p->{swig}) ? ($self->split_like_shell($p->{swig})) : ();
     my @swig_flags = defined($p->{swig_flags}) ? $self->split_like_shell($p->{swig_flags}) : ();
 
     my $blib_lib = catdir(qw/blib lib/);
@@ -215,14 +235,21 @@ sub link_c {
   unless ($self->up_to_date([$obj_file, @$objects], $lib_file)) {
     my @linker_flags = $self->split_like_shell($p->{extra_linker_flags});
 
-    push @linker_flags, $Config{archlib} . '/CORE/' . $Config{libperl} if (is_windows() or is_darwin());
+    if(is_windows() or is_darwin()) {
+      if(is_windows() && $] eq '5.010000' && $Config{archname} =~ /x64/) {
+         push @linker_flags, $Config{bin} . '/' . $Config{libperl};
+      }
+      else {
+        push @linker_flags, $Config{archlib} . '/CORE/' . $Config{libperl};
+      }
+    }
 
     my @lddlflags = $self->split_like_shell($cf->{lddlflags});
     my @shrp = $self->split_like_shell($cf->{shrpenv});
-    my @ld = $self->split_like_shell($cf->{ld}) || "gcc";
+    my @ld = $self->split_like_shell($cf->{ld}) || "$Config{cc}";
 
     # Strip binaries if we are compiling on windows
-    push @ld, "-s" if (is_windows() && $Config{cc} eq 'gcc');
+    push @ld, "-s" if (is_windows() && $Config{cc} =~ /\bgcc\b/i);
 
     $self->do_system(@shrp, @ld, @lddlflags, '-o', $lib_file,
 		     $obj_file, @$objects, @linker_flags)
@@ -272,7 +299,7 @@ sub compile_c {
   my @flags = (@include_dirs, @cccdlflags, '-c', @ccflags, @extra_compiler_flags, );
 
   my @cc = $self->split_like_shell($cf->{cc});
-  @cc = "gcc" unless @cc;
+  @cc = "$Config{cc}" unless @cc;
 
   $self->do_system(@cc, @flags, '-o', $obj_file, $file)
     or die "error building $Config{_o} file from '$file'";
